IE8 ▲ Prism plugins

# How to use

# Examples

## JavaScript

    /**
     * This is a multiline comment
     */
    var foo = 5; // this is a single line comment
    var str = "A string",
        r = /and a regex/;

## CSS

    @font-face {
    	src: url(http://lea.verou.me/logo.otf);
    	font-family: 'LeaVerou';
    }

## HTML

    <!-- A comment -->
    <img src="http://prismjs.com/img/spectrum.png" alt="" />
    <p>Some text</p>